Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(256)

Unified Diff: Source/platform/fonts/shaping/HarfBuzzShaper.cpp

Issue 1119663002: Making Unicode character names consistent (Closed) Base URL: https://chromium.googlesource.com/chromium/blink.git@master
Patch Set: Code changes to correct Test Expectation Created 5 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: Source/platform/fonts/shaping/HarfBuzzShaper.cpp
diff --git a/Source/platform/fonts/shaping/HarfBuzzShaper.cpp b/Source/platform/fonts/shaping/HarfBuzzShaper.cpp
index abb0838164068ff53ead9ff151aa330aefd13cf7..924f4e2be0e0bc3a22f431b5ebe71a82fac0dd9a 100644
--- a/Source/platform/fonts/shaping/HarfBuzzShaper.cpp
+++ b/Source/platform/fonts/shaping/HarfBuzzShaper.cpp
@@ -363,13 +363,13 @@ static void normalizeCharacters(const TextRun& run, unsigned length, UChar* dest
while (position < length) {
UChar32 character;
U16_NEXT(source, position, length, character);
- // Don't normalize tabs as they are not treated as spaces for word-end.
+ // Don't normalize tabs as they are not treated as characterSpaces for word-end.
if (run.normalizeSpace() && Character::isNormalizedCanvasSpaceCharacter(character))
- character = space;
+ character = characterSpace;
else if (Character::treatAsSpace(character) && character != characterTabulation)
- character = space;
+ character = characterSpace;
else if (Character::treatAsZeroWidthSpaceInComplexScript(character))
- character = zeroWidthSpace;
+ character = characterZeroWidthSpace;
U16_APPEND(destination, *destinationLength, length, character, error);
ASSERT_UNUSED(error, !error);
@@ -594,7 +594,7 @@ static inline bool collectCandidateRuns(const UChar* normalizedBuffer,
nextScript = uscript_getScript(character, &errorCode);
if (U_FAILURE(errorCode))
return false;
- if (lastCharacter == zeroWidthJoiner)
+ if (lastCharacter == characterZeroWidthJoiner)
currentFontData = nextFontData;
if ((nextFontData != currentFontData) || ((currentScript != nextScript) && (nextScript != USCRIPT_INHERITED) && (!uscript_hasScript(character, currentScript))))
break;
@@ -852,9 +852,9 @@ bool HarfBuzzShaper::shapeHarfBuzzRuns()
runCache.remove(cachedResults);
}
// Add a space as pre-context to the buffer. This prevents showing dotted-circle
jsbell 2015/05/05 17:29:53 While technically correct, I would not make this c
h.joshi 2015/05/11 07:06:32 Done.
// for combining marks at the beginning of runs.
- static const uint16_t preContext = space;
+ static const uint16_t preContext = characterSpace;
hb_buffer_add_utf16(harfBuzzBuffer.get(), &preContext, 1, 1, 0);
addToHarfBuzzBufferInternal(harfBuzzBuffer.get(),
@@ -1097,7 +1097,7 @@ float HarfBuzzShaper::fillGlyphBufferForTextEmphasis(GlyphBuffer* glyphBuffer, H
float glyphAdvanceX = clusterAdvance / graphemesInCluster;
for (unsigned j = 0; j < graphemesInCluster; ++j) {
// Do not put emphasis marks on space, separator, and control characters.
jsbell 2015/05/05 17:29:53 This comment change is incorrect.
h.joshi 2015/05/11 07:06:32 Done.
if (Character::canReceiveTextEmphasis(m_run[currentCharacterIndex]))
@@ -852,9 +852,9 @@ bool HarfBuzzShaper::shapeHarfBuzzRuns()
runCache.remove(cachedResults);
}
- // Add a space as pre-context to the buffer. This prevents showing dotted-circle
+ // Add a characterSpace as pre-context to the buffer. This prevents showing dotted-circle
jsbell 2015/05/05 17:29:53 While technically correct, I would not make this c
h.joshi 2015/05/11 07:06:32 Done.
@@ -1097,7 +1097,7 @@ float HarfBuzzShaper::fillGlyphBufferForTextEmphasis(GlyphBuffer* glyphBuffer, H
float glyphAdvanceX = clusterAdvance / graphemesInCluster;
for (unsigned j = 0; j < graphemesInCluster; ++j) {
- // Do not put emphasis marks on space, separator, and control characters.
+ // Do not put emphasis marks on characterSpace, separator, and control characters.
jsbell 2015/05/05 17:29:53 This comment change is incorrect.
h.joshi 2015/05/11 07:06:32 Done.
addEmphasisMark(glyphBuffer, advanceSoFar + glyphAdvanceX / 2);

Powered by Google App Engine
This is Rietveld 408576698